@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2014 by The BRLTTY Developers.
+ * Copyright (C) 1995-2017 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://mielke.cc/brltty/
+ * Web Page: http://brltty.com/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -23,6 +23,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
+#define BRL_FLG_PUT(fLG) BRLAPI_KEY_FLG_PUT(fLG)
 /** do nothing */
 #define BRL_CMD_NOOP (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_NOOP)
 /** go up one line */
@@ -49,7 +50,7 @@ extern "C" {
 #define BRL_CMD_TOP_LEFT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TOP_LEFT)
 /** go to beginning of bottom line */
 #define BRL_CMD_BOT_LEFT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_BOT_LEFT)
-/** go up to last line of previous paragraph */
+/** go up to first line of paragraph */
 #define BRL_CMD_PRPGRPH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PRPGRPH)
 /** go down to first line of next paragraph */
 #define BRL_CMD_NXPGRPH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_NXPGRPH)
@@ -65,27 +66,27 @@ extern "C" {
 #define BRL_CMD_CHRLT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CHRLT)
 /** go right one character */
 #define BRL_CMD_CHRRT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CHRRT)
-/** go left half a window */
+/** go left half a braille window */
 #define BRL_CMD_HWINLT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HWINLT)
-/** go right half a window */
+/** go right half a braille window */
 #define BRL_CMD_HWINRT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HWINRT)
-/** go left one window */
+/** go backward one braille window */
 #define BRL_CMD_FWINLT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_FWINLT)
-/** go right one window */
+/** go forward one braille window */
 #define BRL_CMD_FWINRT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_FWINRT)
-/** go left to nearest non-blank window */
+/** go backward skipping blank braille windows */
 #define BRL_CMD_FWINLTSKIP (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_FWINLTSKIP)
-/** go right to nearest non-blank window */
+/** go forward skipping blank braille windows */
 #define BRL_CMD_FWINRTSKIP (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_FWINRTSKIP)
 /** go to beginning of line */
 #define BRL_CMD_LNBEG (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_LNBEG)
 /** go to end of line */
 #define BRL_CMD_LNEND (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_LNEND)
-/** go to cursor */
+/** go to screen cursor */
 #define BRL_CMD_HOME (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOME)
 /** go back after cursor tracking */
 #define BRL_CMD_BACK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_BACK)
-/** go to cursor or go back after cursor tracking */
+/** go to screen cursor or go back after cursor tracking */
 #define BRL_CMD_RETURN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_RETURN)
 /** set screen image frozen/unfrozen */
 #define BRL_CMD_FREEZE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_FREEZE)
@@ -93,21 +94,21 @@ extern "C" {
 #define BRL_CMD_DISPMD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_DISPMD)
 /** set text style 6-dot/8-dot */
 #define BRL_CMD_SIXDOTS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SIXDOTS)
-/** set sliding window on/off */
+/** set sliding braille window on/off */
 #define BRL_CMD_SLIDEWIN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SLIDEWIN)
 /** set skipping of lines with identical content on/off */
 #define BRL_CMD_SKPIDLNS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SKPIDLNS)
-/** set skipping of blank windows on/off */
+/** set skipping of blank braille windows on/off */
 #define BRL_CMD_SKPBLNKWINS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SKPBLNKWINS)
-/** set cursor visibility on/off */
+/** set screen cursor visibility on/off */
 #define BRL_CMD_CSRVIS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRVIS)
-/** set hidden cursor on/off */
+/** set hidden screen cursor on/off */
 #define BRL_CMD_CSRHIDE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRHIDE)
-/** set cursor tracking on/off */
+/** set track screen cursor on/off */
 #define BRL_CMD_CSRTRK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRTRK)
-/** set cursor style block/underline */
+/** set screen cursor style block/underline */
 #define BRL_CMD_CSRSIZE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRSIZE)
-/** set cursor blinking on/off */
+/** set screen cursor blinking on/off */
 #define BRL_CMD_CSRBLINK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRBLINK)
 /** set attribute underlining on/off */
 #define BRL_CMD_ATTRVIS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ATTRVIS)
@@ -133,13 +134,13 @@ extern "C" {
 #define BRL_CMD_PREFSAVE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PREFSAVE)
 /** restore preferences from disk */
 #define BRL_CMD_PREFLOAD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PREFLOAD)
-/** go to first item */
+/** go up to first item */
 #define BRL_CMD_MENU_FIRST_ITEM (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MENU_FIRST_ITEM)
-/** go to last item */
+/** go down to last item */
 #define BRL_CMD_MENU_LAST_ITEM (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MENU_LAST_ITEM)
-/** go to previous item */
+/** go up to previous item */
 #define BRL_CMD_MENU_PREV_ITEM (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MENU_PREV_ITEM)
-/** go to next item */
+/** go down to next item */
 #define BRL_CMD_MENU_NEXT_ITEM (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MENU_NEXT_ITEM)
 /** select previous choice */
 #define BRL_CMD_MENU_PREV_SETTING (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MENU_PREV_SETTING)
@@ -147,7 +148,7 @@ extern "C" {
 #define BRL_CMD_MENU_NEXT_SETTING (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MENU_NEXT_SETTING)
 /** stop speaking */
 #define BRL_CMD_MUTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MUTE)
-/** go to current speech position */
+/** go to current speaking position */
 #define BRL_CMD_SPKHOME (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPKHOME)
 /** speak current line */
 #define BRL_CMD_SAY_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_LINE)
@@ -155,21 +156,21 @@ extern "C" {
 #define BRL_CMD_SAY_ABOVE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_ABOVE)
 /** speak from current line through bottom of screen */
 #define BRL_CMD_SAY_BELOW (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_BELOW)
-/** decrease speech rate */
+/** decrease speaking rate */
 #define BRL_CMD_SAY_SLOWER (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_SLOWER)
-/** increase speech rate */
+/** increase speaking rate */
 #define BRL_CMD_SAY_FASTER (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_FASTER)
-/** decrease speech volume */
+/** decrease speaking volume */
 #define BRL_CMD_SAY_SOFTER (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_SOFTER)
-/** increase speech volume */
+/** increase speaking volume */
 #define BRL_CMD_SAY_LOUDER (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SAY_LOUDER)
-/** switch to previous virtual terminal */
+/** switch to the previous virtual terminal */
 #define BRL_CMD_SWITCHVT_PREV (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SWITCHVT_PREV)
-/** switch to next virtual terminal */
+/** switch to the next virtual terminal */
 #define BRL_CMD_SWITCHVT_NEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SWITCHVT_NEXT)
-/** bring cursor to line */
+/** bring screen cursor to current line */
 #define BRL_CMD_CSRJMP_VERT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRJMP_VERT)
-/** insert clipboard text at cursor */
+/** insert clipboard text after screen cursor */
 #define BRL_CMD_PASTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASTE)
 /** restart braille driver */
 #define BRL_CMD_RESTARTBRL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_RESTARTBRL)
@@ -177,15 +178,15 @@ extern "C" {
 #define BRL_CMD_RESTARTSPEECH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_RESTARTSPEECH)
 /** braille display temporarily unavailable */
 #define BRL_CMD_OFFLINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_OFFLINE)
-/** set shift modifier of next typed character or emulated key on/off */
+/** cycle the Shift sticky input modifier (next, on, off) */
 #define BRL_CMD_SHIFT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SHIFT)
-/** set upper modifier of next typed character or emulated key on/off */
+/** cycle the Upper sticky input modifier (next, on, off) */
 #define BRL_CMD_UPPER (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_UPPER)
-/** set control modifier of next typed character or emulated key on/off */
+/** cycle the Control sticky input modifier (next, on, off) */
 #define BRL_CMD_CONTROL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CONTROL)
-/** set meta modifier of next typed character or emulated key on/off */
+/** cycle the Meta (Left Alt) sticky input modifier (next, on, off) */
 #define BRL_CMD_META (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_META)
-/** show the current date and time */
+/** show current date and time */
 #define BRL_CMD_TIME (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TIME)
 /** go to previous menu level */
 #define BRL_CMD_MENU_PREV_LEVEL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MENU_PREV_LEVEL)
@@ -231,11 +232,11 @@ extern "C" {
 #define BRL_CMD_DESC_CURR_CHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_DESC_CURR_CHAR)
 /** spell current word */
 #define BRL_CMD_SPELL_CURR_WORD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPELL_CURR_WORD)
-/** bring cursor to speech location */
+/** bring screen cursor to speech cursor */
 #define BRL_CMD_ROUTE_CURR_LOCN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE_CURR_LOCN)
-/** speak speech location */
+/** speak speech cursor location */
 #define BRL_CMD_SPEAK_CURR_LOCN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_CURR_LOCN)
-/** set speech location visibility on/off */
+/** set speech cursor visibility on/off */
 #define BRL_CMD_SHOW_CURR_LOCN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SHOW_CURR_LOCN)
 /** save clipboard to disk */
 #define BRL_CMD_CLIP_SAVE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_SAVE)
@@ -245,15 +246,35 @@ extern "C" {
 #define BRL_CMD_BRLUCDOTS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_BRLUCDOTS)
 /** set braille keyboard enabled/disabled */
 #define BRL_CMD_BRLKBD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_BRLKBD)
-/** enable feature */
-#define BRL_FLG_TOGGLE_ON BRLAPI_KEY_FLG_TOGGLE_ON
-/** disable feature */
-#define BRL_FLG_TOGGLE_OFF BRLAPI_KEY_FLG_TOGGLE_OFF
-/** mask for all toggle flags */
-#define BRL_FLG_TOGGLE_MASK BRLAPI_KEY_FLG_TOGGLE_MASK
-/** bring cursor into window after function */
-#define BRL_FLG_MOTION_ROUTE BRLAPI_KEY_FLG_MOTION_ROUTE
-/** bring cursor to character */
+/** clear all sticky input modifiers */
+#define BRL_CMD_UNSTICK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_UNSTICK)
+/** cycle the AltGr (Right Alt) sticky input modifier (next, on, off) */
+#define BRL_CMD_ALTGR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ALTGR)
+/** cycle the GUI (Windows) sticky input modifier (next, on, off) */
+#define BRL_CMD_GUI (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GUI)
+/** stop the braille driver */
+#define BRL_CMD_BRL_STOP (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_BRL_STOP)
+/** start the braille driver */
+#define BRL_CMD_BRL_START (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_BRL_START)
+/** stop the speech driver */
+#define BRL_CMD_SPK_STOP (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPK_STOP)
+/** start the speech driver */
+#define BRL_CMD_SPK_START (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPK_START)
+/** stop the screen driver */
+#define BRL_CMD_SCR_STOP (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SCR_STOP)
+/** start the screen driver */
+#define BRL_CMD_SCR_START (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SCR_START)
+/** bind to the previous virtual terminal */
+#define BRL_CMD_SELECTVT_PREV (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SELECTVT_PREV)
+/** bind to the next virtual terminal */
+#define BRL_CMD_SELECTVT_NEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SELECTVT_NEXT)
+/** go backward to nearest non-blank braille window */
+#define BRL_CMD_PRNBWIN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PRNBWIN)
+/** go forward to nearest non-blank braille window */
+#define BRL_CMD_NXNBWIN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_NXNBWIN)
+/** set touch navigation on/off */
+#define BRL_CMD_TOUCH_NAV (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TOUCH_NAV)
+/** bring screen cursor to character */
 #define BRL_BLK_ROUTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE)
 /** start new clipboard at character */
 #define BRL_BLK_CLIP_NEW (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_NEW)
@@ -271,7 +292,7 @@ extern "C" {
 #define BRL_BLK_COPY_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_COPY_LINE)
 /** deprecated definition of COPY_LINE - linear copy to character */
 #define BRL_BLK_CUTLINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CUTLINE)
-/** switch to virtual terminal */
+/** switch to a specific virtual terminal */
 #define BRL_BLK_SWITCHVT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SWITCHVT)
 /** go up to nearest line with less indent than character */
 #define BRL_BLK_PRINDENT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PRINDENT)
@@ -279,11 +300,11 @@ extern "C" {
 #define BRL_BLK_NXINDENT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_NXINDENT)
 /** describe character */
 #define BRL_BLK_DESCCHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_DESCCHAR)
-/** place left end of window at character */
+/** place left end of braille window at character */
 #define BRL_BLK_SETLEFT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SETLEFT)
-/** remember current window position */
+/** remember current braille window position */
 #define BRL_BLK_SETMARK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SETMARK)
-/** go to remembered window position */
+/** go to remembered braille window position */
 #define BRL_BLK_GOTOMARK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GOTOMARK)
 /** go to selected line */
 #define BRL_BLK_GOTOLINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_GOTOLINE)
@@ -299,21 +320,25 @@ extern "C" {
 #define BRL_BLK_CLIP_APPEND (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_APPEND)
 /** deprecated definition of CLIP_APPEND - append characters to clipboard */
 #define BRL_BLK_APNDCHARS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_APNDCHARS)
-/** insert clipboard history entry at cursor */
+/** insert clipboard history entry after screen cursor */
 #define BRL_BLK_PASTE_HISTORY (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASTE_HISTORY)
-/** set the text table */
+/** set text table */
 #define BRL_BLK_SET_TEXT_TABLE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SET_TEXT_TABLE)
-/** set the attributes table */
+/** set attributes table */
 #define BRL_BLK_SET_ATTRIBUTES_TABLE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SET_ATTRIBUTES_TABLE)
-/** set the contraction table */
+/** set contraction table */
 #define BRL_BLK_SET_CONTRACTION_TABLE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SET_CONTRACTION_TABLE)
-/** set the keyboard table */
+/** set keyboard table */
 #define BRL_BLK_SET_KEYBOARD_TABLE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SET_KEYBOARD_TABLE)
-/** set the language profile */
+/** set language profile */
 #define BRL_BLK_SET_LANGUAGE_PROFILE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SET_LANGUAGE_PROFILE)
+/** bind to a specific virtual terminal */
+#define BRL_BLK_SELECTVT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SELECTVT)
+/** render an alert */
+#define BRL_BLK_ALERT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ALERT)
 /** type unicode character */
 #define BRL_KEY_PASSCHAR (BRLAPI_KEY_TYPE_SYM | 0X0000)
-/** type braille character */
+/** type braille dots */
 #define BRL_BLK_PASSDOTS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASSDOTS)
 /** AT (set 2) keyboard scan code */
 #define BRL_BLK_PASSAT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASSAT)
@@ -324,7 +349,7 @@ extern "C" {
 /** switch to command context */
 #define BRL_BLK_CONTEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CONTEXT)
 /** current reading location */
-#define BRL_BLK_TOUCH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TOUCH)
+#define BRL_BLK_TOUCH_AT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TOUCH_AT)
 /** enter key */
 #define BRL_KEY_ENTER (BRLAPI_KEY_SYM_LINEFEED & 0XFF)
 /** tab key */
@@ -355,18 +380,30 @@ extern "C" {
 #define BRL_KEY_DELETE (BRLAPI_KEY_SYM_DELETE & 0XFF)
 /** function key */
 #define BRL_KEY_FUNCTION (BRLAPI_KEY_SYM_FUNCTION & 0XFF)
+/** enable feature */
+#define BRL_FLG_TOGGLE_ON BRLAPI_KEY_FLG_TOGGLE_ON
+/** disable feature */
+#define BRL_FLG_TOGGLE_OFF BRLAPI_KEY_FLG_TOGGLE_OFF
+/** mask for all toggle flags */
+#define BRL_FLG_TOGGLE_MASK BRLAPI_KEY_FLG_TOGGLE_MASK
+/** bring screen cursor into braille window after function */
+#define BRL_FLG_MOTION_ROUTE BRLAPI_KEY_FLG_MOTION_ROUTE
 /** scale arg=0X00-0XFF to screen height */
-#define BRL_FLG_LINE_SCALED BRLAPI_KEY_FLG_LINE_SCALED
+#define BRL_FLG_MOTION_SCALED BRLAPI_KEY_FLG_MOTION_SCALED
 /** go to beginning of line */
-#define BRL_FLG_LINE_TOLEFT BRLAPI_KEY_FLG_LINE_TOLEFT
+#define BRL_FLG_MOTION_TOLEFT BRLAPI_KEY_FLG_MOTION_TOLEFT
 /** shift key pressed */
-#define BRL_FLG_CHAR_SHIFT BRLAPI_KEY_FLG_SHIFT
+#define BRL_FLG_INPUT_SHIFT BRLAPI_KEY_FLG_INPUT_SHIFT
 /** convert to uppercase */
-#define BRL_FLG_CHAR_UPPER BRLAPI_KEY_FLG_UPPER
+#define BRL_FLG_INPUT_UPPER BRLAPI_KEY_FLG_INPUT_UPPER
 /** control key pressed */
-#define BRL_FLG_CHAR_CONTROL BRLAPI_KEY_FLG_CONTROL
-/** meta key pressed */
-#define BRL_FLG_CHAR_META BRLAPI_KEY_FLG_META
+#define BRL_FLG_INPUT_CONTROL BRLAPI_KEY_FLG_INPUT_CONTROL
+/** meta (left alt) key pressed */
+#define BRL_FLG_INPUT_META BRLAPI_KEY_FLG_INPUT_META
+/** altgr (right alt) key pressed */
+#define BRL_FLG_INPUT_ALTGR BRLAPI_KEY_FLG_INPUT_ALTGR
+/** gui (windows) key pressed */
+#define BRL_FLG_INPUT_GUI BRLAPI_KEY_FLG_INPUT_GUI
 /** it is a release scan code */
 #define BRL_FLG_KBD_RELEASE BRLAPI_KEY_FLG_KBD_RELEASE
 /** it is an emulation 0 scan code */
@@ -389,7 +426,7 @@ extern "C" {
 #define BRL_DOT7 BRLAPI_DOT7
 /** lower-right dot of computer braille cell */
 #define BRL_DOT8 BRLAPI_DOT8
-/** space key pressed */
+/** chord (space bar on braille keyboard) */
 #define BRL_DOTC BRLAPI_DOTC
 /** mask for command type */
 #define BRL_MSK_BLK (BRLAPI_KEY_TYPE_MASK | BRLAPI_KEY_CMD_BLK_MASK)
