@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2015 by The BRLTTY Developers.
+ * Copyright (C) 1995-2017 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -25,7 +25,7 @@ extern "C" {
 
 typedef enum {
   MSG_SILENT  = 0X1, /* don't speak the message */
-  MSG_WAITKEY = 0X2, /* wait for a key press before scrolling or dismissing the message */
+  MSG_LOG     = 0X2, /* add the message to the log's message stack */
   MSG_NODELAY = 0X4, /* don't wait */
   MSG_SYNC    = 0X8  /* run synchronously */
 } MessageOptions;
